<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>MircastShowWidget</name>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="57"/>
        <source>Exit Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="74"/>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="102"/>
        <source>Display device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="67"/>
        <source>Project to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="336"/>
        <source>Searching for devices...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="345"/>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="477"/>
        <location filename="../src/main.cpp" line="181"/>
        <location filename="../src/main.cpp" line="219"/>
        <location filename="../src/widgets/volumeslider.cpp" line="113"/>
        <location filename="../src/widgets/platform/platform_volumeslider.cpp" line="116"/>
        <location filename="../src/common/volumemonitoring.cpp" line="68"/>
        <location filename="../src/common/dmr_settings.cpp" line="192"/>
        <source>Movie</source>
        <translation>Film</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="182"/>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="186"/>
        <location filename="../src/common/settings_translation.cpp" line="59"/>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="189"/>
        <location filename="../src/common/settings_translation.cpp" line="57"/>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <location filename="../src/common/shortcut_manager.cpp" line="194"/>
        <location filename="../src/common/settings_translation.cpp" line="58"/>
        <source>Display shortcuts</source>
        <translation>Tampilkan pintasan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="10"/>
        <source>Auto add similar files to play</source>
        <translation>Otomatis tambah berkas yang sama untuk dimainkan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="11"/>
        <source>Clear playlist when exit</source>
        <translation>Bersih playlist ketika keluar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="12"/>
        <source>Show thumbnails in progress bar</source>
        <translation>Tunjukkan gambar mini di bilah kemajuan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="13"/>
        <source>Show video preview on mouseover</source>
        <translation>Tampilkan pratinjau video di atas tetikus</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="14"/>
        <source>Open a new player for each file played</source>
        <translation>Buka pemutar baru untuk setiap berkas yang dimainkan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="15"/>
        <source>Pause when minimized</source>
        <translation>Jeda ketika diminimalkan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="16"/>
        <source>Remember playback position</source>
        <translation>Mengingat posisi playback</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="17"/>
        <source>Default play mode</source>
        <translation>Mode putar bawaan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="18"/>
        <source>Path</source>
        <translation>Jejak</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="19"/>
        <source>Basic</source>
        <translation>Dasar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="20"/>
        <source>Play</source>
        <translation>Putar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="21"/>
        <location filename="../src/common/settings_translation.cpp" line="26"/>
        <source>Screenshot</source>
        <translation>Tangkapan Layar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="22"/>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="23"/>
        <source>File</source>
        <translation>Berkas</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="24"/>
        <source>Frame/Sound</source>
        <translation>Bingkai/Suara</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="25"/>
        <source>Playback</source>
        <translation>Pemutaran</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="27"/>
        <location filename="../src/common/settings_translation.cpp" line="28"/>
        <source>Subtitle</source>
        <translation>Subtitle</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="29"/>
        <source>Font Style</source>
        <translation>Gaya Fonta</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="30"/>
        <source>Restore Defaults</source>
        <translation>Pulihkan baku</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="31"/>
        <source>Open file</source>
        <translation>Buka berkas</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="32"/>
        <source>Open next</source>
        <translation>Buka selanjutnya</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="33"/>
        <source>Open previous</source>
        <translation>Buka sebelumnya</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="34"/>
        <source>Mini mode</source>
        <translation>Mode Mini</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="35"/>
        <source>Mute</source>
        <translation>Senyap</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="36"/>
        <source>Next frame</source>
        <translation>Frame sesudah</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="37"/>
        <source>Previous frame</source>
        <translation>Frame sebelum</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="38"/>
        <source>Volume down</source>
        <translation>Turunkan Volume</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="39"/>
        <source>Volume up</source>
        <translation>Naikkan Volume</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="40"/>
        <source>Speed up</source>
        <translation>Percepat</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="41"/>
        <source>Speed down</source>
        <translation>Turun cepat</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="42"/>
        <source>Fullscreen</source>
        <translation>Layar Penuh</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="43"/>
        <source>Pause/Play</source>
        <translation>Jeda/Putar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="44"/>
        <source>Playlist</source>
        <translation>Daftar Putar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="45"/>
        <source>Reset speed</source>
        <translation>Reset kecepatan</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="46"/>
        <source>Delete from playlist</source>
        <translation>Hapus dari daftar putar</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="47"/>
        <source>Film info</source>
        <translation>Info Film</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="48"/>
        <source>Rewind</source>
        <translation>Mundur</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="49"/>
        <source>Forward</source>
        <translation>Maju</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="50"/>
        <source>Burst shooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="51"/>
        <source>Film screenshot</source>
        <translation>Tangkapan layar Film</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="52"/>
        <source>0.5s backward</source>
        <translation>Putar awal 0.5s</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="53"/>
        <source>0.5s forward</source>
        <translation>Putar maju 0.5s</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="54"/>
        <source>Font</source>
        <translation>Fon</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="55"/>
        <source>Size</source>
        <translation>Ukuran</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="56"/>
        <source>Exit fullscreen/mini mode</source>
        <translation>Keluar dari mode layarpenuh/mini</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="60"/>
        <source>Decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="61"/>
        <source>Auto select (Recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="62"/>
        <source>Hardware decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="63"/>
        <source>Software decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="201"/>
        <location filename="../src/common/mainwindow.cpp" line="203"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Anda tidak mempunyai ijin untuk beroperasi di folder ini</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="203"/>
        <location filename="../src/common/mainwindow.cpp" line="205"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="219"/>
        <location filename="../src/common/mainwindow.cpp" line="221"/>
        <source>Invalid folder</source>
        <translation>Folder tidak valid</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="239"/>
        <location filename="../src/common/mainwindow.cpp" line="241"/>
        <source>Open folder</source>
        <translation>Buka Folder</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2906"/>
        <location filename="../src/common/mainwindow.cpp" line="2875"/>
        <source>Network disconnected</source>
        <translation>Jaringan terputus</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="17"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="18"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="22"/>
        <source>Please enter the URL:</source>
        <translation>Mohon masukan URL:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../src/common/actions.cpp" line="53"/>
        <location filename="../src/common/actions.cpp" line="127"/>
        <location filename="../src/common/actions.cpp" line="314"/>
        <source>Open file</source>
        <translation>Buka berkas</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="55"/>
        <location filename="../src/common/actions.cpp" line="128"/>
        <location filename="../src/common/actions.cpp" line="315"/>
        <source>Open folder</source>
        <translation>Buka Folder</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="56"/>
        <location filename="../src/common/actions.cpp" line="310"/>
        <location filename="../src/common/actions.cpp" line="366"/>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="66"/>
        <location filename="../src/common/actions.cpp" line="138"/>
        <location filename="../src/common/actions.cpp" line="325"/>
        <source>Play Mode</source>
        <translation>Mode main</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="68"/>
        <location filename="../src/common/actions.cpp" line="140"/>
        <location filename="../src/common/actions.cpp" line="327"/>
        <source>Order Play</source>
        <translation>Putar secara urut</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="69"/>
        <location filename="../src/common/actions.cpp" line="141"/>
        <location filename="../src/common/actions.cpp" line="328"/>
        <source>Shuffle Play</source>
        <translation>Putar secara acak</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="70"/>
        <location filename="../src/common/actions.cpp" line="142"/>
        <location filename="../src/common/actions.cpp" line="329"/>
        <source>Single Play</source>
        <translation>Putar tunggal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="71"/>
        <location filename="../src/common/actions.cpp" line="143"/>
        <location filename="../src/common/actions.cpp" line="330"/>
        <source>Single Loop</source>
        <translation>Putar sekali</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="72"/>
        <location filename="../src/common/actions.cpp" line="144"/>
        <location filename="../src/common/actions.cpp" line="331"/>
        <source>List Loop</source>
        <translation>Daftar putar</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="77"/>
        <location filename="../src/common/actions.cpp" line="164"/>
        <source>Frame</source>
        <translation>Bingkai</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="79"/>
        <location filename="../src/common/actions.cpp" line="166"/>
        <source>Default</source>
        <translation>Bawaan</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="86"/>
        <location filename="../src/common/actions.cpp" line="173"/>
        <source>Clockwise</source>
        <translation>Searah jarum jam</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="87"/>
        <location filename="../src/common/actions.cpp" line="174"/>
        <source>Counterclockwise</source>
        <translation>Searah jarum jam</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="89"/>
        <location filename="../src/common/actions.cpp" line="176"/>
        <source>Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="90"/>
        <location filename="../src/common/actions.cpp" line="177"/>
        <source>Previous Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="99"/>
        <location filename="../src/common/actions.cpp" line="149"/>
        <location filename="../src/common/actions.cpp" line="336"/>
        <source>Playback Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="101"/>
        <location filename="../src/common/actions.cpp" line="151"/>
        <location filename="../src/common/actions.cpp" line="338"/>
        <source>0.5x</source>
        <translation>0.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="102"/>
        <location filename="../src/common/actions.cpp" line="152"/>
        <location filename="../src/common/actions.cpp" line="339"/>
        <source>1.0x</source>
        <translation>1.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="103"/>
        <location filename="../src/common/actions.cpp" line="153"/>
        <location filename="../src/common/actions.cpp" line="340"/>
        <source>1.2x</source>
        <translation>1.2x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="104"/>
        <location filename="../src/common/actions.cpp" line="154"/>
        <location filename="../src/common/actions.cpp" line="341"/>
        <source>1.5x</source>
        <translation>1.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="105"/>
        <location filename="../src/common/actions.cpp" line="155"/>
        <location filename="../src/common/actions.cpp" line="342"/>
        <source>2.0x</source>
        <translation>2.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="129"/>
        <location filename="../src/common/actions.cpp" line="316"/>
        <source>Open URL</source>
        <translation>Buka URL</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="130"/>
        <location filename="../src/common/actions.cpp" line="317"/>
        <source>Open CD/DVD</source>
        <translation>Buka CD/DVD</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="132"/>
        <location filename="../src/common/actions.cpp" line="319"/>
        <source>Fullscreen</source>
        <translation>Layar Penuh</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="133"/>
        <location filename="../src/common/actions.cpp" line="320"/>
        <source>Mini Mode</source>
        <translation>Mode Mini</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="134"/>
        <location filename="../src/common/actions.cpp" line="321"/>
        <source>Always on Top</source>
        <translation>Selalu di atas</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="187"/>
        <source>Sound</source>
        <translation>Suara</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="191"/>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="194"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="195"/>
        <source>Left channel</source>
        <translation>Kanal kiri</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="196"/>
        <source>Right channel</source>
        <translation>Kanal kanan</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="201"/>
        <location filename="../src/common/actions.cpp" line="424"/>
        <source>Track</source>
        <translation>Lagu</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="214"/>
        <source>Subtitle</source>
        <translation>Subtitle</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="216"/>
        <source>Load</source>
        <translation>Muat</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="217"/>
        <source>Online Search</source>
        <translation>Cari Online</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="221"/>
        <source>Select</source>
        <translation>Pilih</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="225"/>
        <source>Hide</source>
        <translation>Sembunyi</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="228"/>
        <source>Encodings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="295"/>
        <location filename="../src/common/actions.cpp" line="352"/>
        <source>Screenshot</source>
        <translation>Tangkapan Layar</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="298"/>
        <location filename="../src/common/actions.cpp" line="355"/>
        <source>Film Screenshot</source>
        <translation>Tangkapan layar Film</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="299"/>
        <source>Burst Shooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="300"/>
        <location filename="../src/common/actions.cpp" line="356"/>
        <source>Open screenshot folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="308"/>
        <location filename="../src/common/actions.cpp" line="364"/>
        <source>Playlist</source>
        <translation>Daftar Putar</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="309"/>
        <location filename="../src/common/actions.cpp" line="365"/>
        <source>Film Info</source>
        <translation>Info Film</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="375"/>
        <source>Delete from playlist</source>
        <translation>Hapus dari daftar putar</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="376"/>
        <source>Empty playlist</source>
        <translation>Daftar putar kosong</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="377"/>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="378"/>
        <source>Film info</source>
        <translation>Info Film</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="44"/>
        <source>Duration: %1</source>
        <translation>Durasi: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="49"/>
        <source>Resolution: %1</source>
        <translation>Resolusi: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="54"/>
        <source>Size: %1</source>
        <translation>Ukuran: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="77"/>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="852"/>
        <location filename="../src/common/mainwindow.cpp" line="2355"/>
        <location filename="../src/common/mainwindow.cpp" line="4225"/>
        <source>Load successfully</source>
        <translation>Berhasil dimuat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="852"/>
        <location filename="../src/common/mainwindow.cpp" line="2355"/>
        <location filename="../src/common/mainwindow.cpp" line="2358"/>
        <location filename="../src/common/mainwindow.cpp" line="4225"/>
        <source>Load failed</source>
        <translation>Gagal dimuat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1695"/>
        <location filename="../src/common/mainwindow.cpp" line="2685"/>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1712"/>
        <location filename="../src/common/mainwindow.cpp" line="3206"/>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1720"/>
        <source>Open folder</source>
        <translation>Buka Folder</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2092"/>
        <location filename="../src/common/mainwindow.cpp" line="2100"/>
        <location filename="../src/common/mainwindow.cpp" line="2108"/>
        <location filename="../src/common/mainwindow.cpp" line="2116"/>
        <location filename="../src/common/mainwindow.cpp" line="2124"/>
        <location filename="../src/common/mainwindow.cpp" line="2330"/>
        <location filename="../src/common/mainwindow.cpp" line="4409"/>
        <source>Speed: %1x</source>
        <translation>Cepat: %1x</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2131"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2136"/>
        <source>Left channel</source>
        <translation>Kanal kiri</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2141"/>
        <source>Right channel</source>
        <translation>Kanal kanan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2246"/>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2288"/>
        <location filename="../src/common/mainwindow.cpp" line="2305"/>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2293"/>
        <location filename="../src/common/mainwindow.cpp" line="2310"/>
        <source>Subtitle %1: %2s</source>
        <translation>Translasi %1: %2s</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2294"/>
        <location filename="../src/common/mainwindow.cpp" line="2311"/>
        <source>delayed</source>
        <translation>Penundaan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2294"/>
        <location filename="../src/common/mainwindow.cpp" line="2311"/>
        <source>advanced</source>
        <translation>Terkini</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2452"/>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2461"/>
        <source>Film screenshot</source>
        <translation>Tangkapan layar Film</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2462"/>
        <source>Saved to</source>
        <translation>Disimpan ke</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2483"/>
        <location filename="../src/common/mainwindow.cpp" line="2611"/>
        <source>The screenshot is saved</source>
        <translation>Tangkapan layar di simpan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2487"/>
        <location filename="../src/common/mainwindow.cpp" line="2615"/>
        <source>Failed to save the screenshot</source>
        <translation>Gagal menyimpan tangkapan layar</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2571"/>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2690"/>
        <source>Reading DVD files...</source>
        <translation>Membaca berkas-berkas DVD...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4521"/>
        <source>Invalid file: %1</source>
        <translation>Berkas tidak valid: %1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4552"/>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2882"/>
        <source>No matching online subtitles</source>
        <translation>Tidak menemukan terjemahan daring yang cocok</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1756"/>
        <location filename="../src/common/mainwindow.cpp" line="1793"/>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2898"/>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2899"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2931"/>
        <location filename="../src/common/mainwindow.cpp" line="3855"/>
        <source>Order play</source>
        <translation>Urutan memainkan</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2934"/>
        <location filename="../src/common/mainwindow.cpp" line="3858"/>
        <source>Shuffle play</source>
        <translation>Mainkan acak</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2937"/>
        <location filename="../src/common/mainwindow.cpp" line="3861"/>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2940"/>
        <location filename="../src/common/mainwindow.cpp" line="3864"/>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2943"/>
        <location filename="../src/common/mainwindow.cpp" line="3867"/>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3097"/>
        <source>Buffering...</source>
        <translation>Penyanggaan ...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3120"/>
        <location filename="../src/common/mainwindow.cpp" line="3145"/>
        <source>Mute</source>
        <translation>Senyap</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3122"/>
        <location filename="../src/common/mainwindow.cpp" line="3147"/>
        <source>Volume: %1%</source>
        <translation>Volume: %1%</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3165"/>
        <location filename="../src/common/mainwindow.cpp" line="3197"/>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4510"/>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4545"/>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3214"/>
        <location filename="../src/common/mainwindow.cpp" line="3219"/>
        <source>Invalid file</source>
        <translation>Berkas tidak valid</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2339"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Translasi (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3221"/>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3226"/>
        <source>No video file found</source>
        <translation>Tidak ditemukan berkas video</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3846"/>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3969"/>
        <location filename="../src/common/mainwindow.cpp" line="3977"/>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4270"/>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="obsolete">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="obsolete">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="obsolete">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="obsolete">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="243"/>
        <source>Film info</source>
        <translation>Info Film</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="295"/>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="296"/>
        <source>Size</source>
        <translation>Ukuran</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="297"/>
        <source>Duration</source>
        <translation>Durasi</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="302"/>
        <source>Path</source>
        <translation>Jejak</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="307"/>
        <source>Codec info</source>
        <translation>Info Codec</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="328"/>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="329"/>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="275"/>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="288"/>
        <source>%1 kbps</source>
        <translation>%1 kbps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="276"/>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="289"/>
        <source>%1 bps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="330"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="278"/>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="331"/>
        <source>Proportion</source>
        <translation>Proporsi</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="279"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="332"/>
        <source>Resolution</source>
        <translation>Resolusi</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="337"/>
        <source>Audio info</source>
        <translation>Info audio</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="358"/>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="359"/>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="360"/>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="291"/>
        <source>%1 bits</source>
        <translation>%1 bits</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="361"/>
        <source>Channels</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="292"/>
        <source>%1 channels</source>
        <translation>%1 kanal</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="362"/>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="293"/>
        <source>%1hz</source>
        <translation>%1hz</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="1744"/>
        <source>Internal</source>
        <translation>Internal</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="874"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2397"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4198"/>
        <source>Load successfully</source>
        <translation type="unfinished">Berhasil dimuat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="874"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2397"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2400"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4198"/>
        <source>Load failed</source>
        <translation type="unfinished">Gagal dimuat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1755"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2736"/>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1772"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3224"/>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1780"/>
        <source>Open folder</source>
        <translation type="unfinished">Buka Folder</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1808"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1837"/>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2134"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2142"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2150"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2158"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2166"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2372"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4382"/>
        <source>Speed: %1x</source>
        <translation type="unfinished">Cepat: %1x</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2173"/>
        <source>Stereo</source>
        <translation type="unfinished">Stereo</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2178"/>
        <source>Left channel</source>
        <translation type="unfinished">Kanal kiri</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2183"/>
        <source>Right channel</source>
        <translation type="unfinished">Kanal kanan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2288"/>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2330"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2347"/>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2335"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2352"/>
        <source>Subtitle %1: %2s</source>
        <translation type="unfinished">Translasi %1: %2s</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2336"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2353"/>
        <source>delayed</source>
        <translation type="unfinished">Penundaan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2336"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2353"/>
        <source>advanced</source>
        <translation type="unfinished">Terkini</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2381"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Translasi (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2504"/>
        <source>View</source>
        <translation type="unfinished">Lihat</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2513"/>
        <source>Film screenshot</source>
        <translation type="unfinished">Tangkapan layar Film</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2514"/>
        <source>Saved to</source>
        <translation type="unfinished">Disimpan ke</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2535"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2662"/>
        <source>The screenshot is saved</source>
        <translation type="unfinished">Tangkapan layar di simpan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2539"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2666"/>
        <source>Failed to save the screenshot</source>
        <translation type="unfinished">Gagal menyimpan tangkapan layar</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2623"/>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2741"/>
        <source>Reading DVD files...</source>
        <translation type="unfinished">Membaca berkas-berkas DVD...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2913"/>
        <source>No matching online subtitles</source>
        <translation type="unfinished">Tidak menemukan terjemahan daring yang cocok</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2929"/>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2930"/>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2971"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3884"/>
        <source>Order play</source>
        <translation type="unfinished">Urutan memainkan</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2974"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3887"/>
        <source>Shuffle play</source>
        <translation type="unfinished">Mainkan acak</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2977"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3890"/>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2980"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3893"/>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2983"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3896"/>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3121"/>
        <source>Buffering...</source>
        <translation type="unfinished">Penyanggaan ...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3144"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3169"/>
        <source>Mute</source>
        <translation type="unfinished">Senyap</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3146"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3171"/>
        <source>Volume: %1%</source>
        <translation type="unfinished">Volume: %1%</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3215"/>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3232"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3237"/>
        <source>Invalid file</source>
        <translation type="unfinished">Berkas tidak valid</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3239"/>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3244"/>
        <source>No video file found</source>
        <translation type="unfinished">Tidak ditemukan berkas video</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3875"/>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3995"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4002"/>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4243"/>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4483"/>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4494"/>
        <source>Invalid file: %1</source>
        <translation type="unfinished">Berkas tidak valid: %1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4518"/>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4525"/>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="163"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="222"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="288"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="474"/>
        <source>The file does not exist</source>
        <translation type="unfinished">Berkas tidak ada</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="646"/>
        <source>Playlist</source>
        <translation type="unfinished">Daftar Putar</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="672"/>
        <source>Empty</source>
        <translation type="unfinished">Kosong</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="861"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1169"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1251"/>
        <source>%1 videos</source>
        <translation type="unfinished">%1 video</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Play/Pause</source>
        <translation type="unfinished">Mainkan/Jeda</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Previous</source>
        <translation type="unfinished">Sebelumnya</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1143"/>
        <source>Next</source>
        <translation type="unfinished">Selanjutnya</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1999"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2447"/>
        <source>Fullscreen</source>
        <translation type="unfinished">Layar Penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2464"/>
        <source>Playlist</source>
        <translation type="unfinished">Daftar Putar</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1144"/>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1996"/>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Keluar layar penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2081"/>
        <source>Pause</source>
        <translation type="unfinished">Jeda</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2141"/>
        <source>Play</source>
        <translation type="unfinished">Putar</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="163"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="222"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="288"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="474"/>
        <source>The file does not exist</source>
        <translation>Berkas tidak ada</translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="646"/>
        <source>Playlist</source>
        <translation>Daftar Putar</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="672"/>
        <source>Empty</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="861"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1144"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1169"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1251"/>
        <source>%1 videos</source>
        <translation>%1 video</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="73"/>
        <source>Order play</source>
        <translation>Urutan memainkan</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="74"/>
        <source>Shuffle play</source>
        <translation>Mainkan acak</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="75"/>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="76"/>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="77"/>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="82"/>
        <source>Auto</source>
        <translation>Otomatis</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="83"/>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="84"/>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="201"/>
        <source>%1/Movie%2(%3).jpg</source>
        <translation>%1/Movie%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <source>Play/Pause</source>
        <translation>Mainkan/Jeda</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2573"/>
        <source>Previous</source>
        <translation>Sebelumnya</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1216"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2590"/>
        <source>Next</source>
        <translation>Selanjutnya</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2114"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2116"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2607"/>
        <source>Fullscreen</source>
        <translation>Layar Penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2623"/>
        <source>Playlist</source>
        <translation>Daftar Putar</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1217"/>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2108"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2110"/>
        <source>Exit fullscreen</source>
        <translation>Keluar layar penuh</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2204"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2206"/>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2269"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2271"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2558"/>
        <source>Play</source>
        <translation>Putar</translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <location filename="../src/widgets/toolbutton.cpp" line="18"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
